Files
TheRock/math-libs/libhipcxx/include/cuda/__ptx/instructions/generated/bfind.h
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

191 lines
6.1 KiB
C++

// This file was automatically generated. Do not edit.
#ifndef _CUDA_PTX_GENERATED_BFIND_H_
#define _CUDA_PTX_GENERATED_BFIND_H_
/*
// bfind.u32 dest, a_reg; // PTX ISA 20, SM_50
template <typename = void>
__device__ static inline uint32_t bfind(
uint32_t a_reg);
*/
#if __cccl_ptx_isa >= 200
extern "C" _CCCL_DEVICE void __cuda_ptx_bfind_is_not_supported_before_SM_50__();
template <typename = void>
_CCCL_DEVICE static inline _CUDA_VSTD::uint32_t bfind(_CUDA_VSTD::uint32_t __a_reg)
{
# if _CCCL_CUDA_COMPILER(NVHPC) || __CUDA_ARCH__ >= 500
_CUDA_VSTD::uint32_t __dest;
asm("bfind.u32 %0, %1;" : "=r"(__dest) : "r"(__a_reg) :);
return __dest;
# else
// Unsupported architectures will have a linker error with a semi-decent error message
__cuda_ptx_bfind_is_not_supported_before_SM_50__();
return 0;
# endif
}
#endif // __cccl_ptx_isa >= 200
/*
// bfind.shiftamt.u32 dest, a_reg; // PTX ISA 20, SM_50
template <typename = void>
__device__ static inline uint32_t bfind_shiftamt(
uint32_t a_reg);
*/
#if __cccl_ptx_isa >= 200
extern "C" _CCCL_DEVICE void __cuda_ptx_bfind_shiftamt_is_not_supported_before_SM_50__();
template <typename = void>
_CCCL_DEVICE static inline _CUDA_VSTD::uint32_t bfind_shiftamt(_CUDA_VSTD::uint32_t __a_reg)
{
# if _CCCL_CUDA_COMPILER(NVHPC) || __CUDA_ARCH__ >= 500
_CUDA_VSTD::uint32_t __dest;
asm("bfind.shiftamt.u32 %0, %1;" : "=r"(__dest) : "r"(__a_reg) :);
return __dest;
# else
// Unsupported architectures will have a linker error with a semi-decent error message
__cuda_ptx_bfind_shiftamt_is_not_supported_before_SM_50__();
return 0;
# endif
}
#endif // __cccl_ptx_isa >= 200
/*
// bfind.u64 dest, a_reg; // PTX ISA 20, SM_50
template <typename = void>
__device__ static inline uint32_t bfind(
uint64_t a_reg);
*/
#if __cccl_ptx_isa >= 200
extern "C" _CCCL_DEVICE void __cuda_ptx_bfind_is_not_supported_before_SM_50__();
template <typename = void>
_CCCL_DEVICE static inline _CUDA_VSTD::uint32_t bfind(_CUDA_VSTD::uint64_t __a_reg)
{
# if _CCCL_CUDA_COMPILER(NVHPC) || __CUDA_ARCH__ >= 500
_CUDA_VSTD::uint32_t __dest;
asm("bfind.u64 %0, %1;" : "=r"(__dest) : "l"(__a_reg) :);
return __dest;
# else
// Unsupported architectures will have a linker error with a semi-decent error message
__cuda_ptx_bfind_is_not_supported_before_SM_50__();
return 0;
# endif
}
#endif // __cccl_ptx_isa >= 200
/*
// bfind.shiftamt.u64 dest, a_reg; // PTX ISA 20, SM_50
template <typename = void>
__device__ static inline uint32_t bfind_shiftamt(
uint64_t a_reg);
*/
#if __cccl_ptx_isa >= 200
extern "C" _CCCL_DEVICE void __cuda_ptx_bfind_shiftamt_is_not_supported_before_SM_50__();
template <typename = void>
_CCCL_DEVICE static inline _CUDA_VSTD::uint32_t bfind_shiftamt(_CUDA_VSTD::uint64_t __a_reg)
{
# if _CCCL_CUDA_COMPILER(NVHPC) || __CUDA_ARCH__ >= 500
_CUDA_VSTD::uint32_t __dest;
asm("bfind.shiftamt.u64 %0, %1;" : "=r"(__dest) : "l"(__a_reg) :);
return __dest;
# else
// Unsupported architectures will have a linker error with a semi-decent error message
__cuda_ptx_bfind_shiftamt_is_not_supported_before_SM_50__();
return 0;
# endif
}
#endif // __cccl_ptx_isa >= 200
/*
// bfind.s32 dest, a_reg; // PTX ISA 20, SM_50
template <typename = void>
__device__ static inline uint32_t bfind(
int32_t a_reg);
*/
#if __cccl_ptx_isa >= 200
extern "C" _CCCL_DEVICE void __cuda_ptx_bfind_is_not_supported_before_SM_50__();
template <typename = void>
_CCCL_DEVICE static inline _CUDA_VSTD::uint32_t bfind(_CUDA_VSTD::int32_t __a_reg)
{
# if _CCCL_CUDA_COMPILER(NVHPC) || __CUDA_ARCH__ >= 500
_CUDA_VSTD::uint32_t __dest;
asm("bfind.s32 %0, %1;" : "=r"(__dest) : "r"(__a_reg) :);
return __dest;
# else
// Unsupported architectures will have a linker error with a semi-decent error message
__cuda_ptx_bfind_is_not_supported_before_SM_50__();
return 0;
# endif
}
#endif // __cccl_ptx_isa >= 200
/*
// bfind.shiftamt.s32 dest, a_reg; // PTX ISA 20, SM_50
template <typename = void>
__device__ static inline uint32_t bfind_shiftamt(
int32_t a_reg);
*/
#if __cccl_ptx_isa >= 200
extern "C" _CCCL_DEVICE void __cuda_ptx_bfind_shiftamt_is_not_supported_before_SM_50__();
template <typename = void>
_CCCL_DEVICE static inline _CUDA_VSTD::uint32_t bfind_shiftamt(_CUDA_VSTD::int32_t __a_reg)
{
# if _CCCL_CUDA_COMPILER(NVHPC) || __CUDA_ARCH__ >= 500
_CUDA_VSTD::uint32_t __dest;
asm("bfind.shiftamt.s32 %0, %1;" : "=r"(__dest) : "r"(__a_reg) :);
return __dest;
# else
// Unsupported architectures will have a linker error with a semi-decent error message
__cuda_ptx_bfind_shiftamt_is_not_supported_before_SM_50__();
return 0;
# endif
}
#endif // __cccl_ptx_isa >= 200
/*
// bfind.s64 dest, a_reg; // PTX ISA 20, SM_50
template <typename = void>
__device__ static inline uint32_t bfind(
int64_t a_reg);
*/
#if __cccl_ptx_isa >= 200
extern "C" _CCCL_DEVICE void __cuda_ptx_bfind_is_not_supported_before_SM_50__();
template <typename = void>
_CCCL_DEVICE static inline _CUDA_VSTD::uint32_t bfind(_CUDA_VSTD::int64_t __a_reg)
{
# if _CCCL_CUDA_COMPILER(NVHPC) || __CUDA_ARCH__ >= 500
_CUDA_VSTD::uint32_t __dest;
asm("bfind.s64 %0, %1;" : "=r"(__dest) : "l"(__a_reg) :);
return __dest;
# else
// Unsupported architectures will have a linker error with a semi-decent error message
__cuda_ptx_bfind_is_not_supported_before_SM_50__();
return 0;
# endif
}
#endif // __cccl_ptx_isa >= 200
/*
// bfind.shiftamt.s64 dest, a_reg; // PTX ISA 20, SM_50
template <typename = void>
__device__ static inline uint32_t bfind_shiftamt(
int64_t a_reg);
*/
#if __cccl_ptx_isa >= 200
extern "C" _CCCL_DEVICE void __cuda_ptx_bfind_shiftamt_is_not_supported_before_SM_50__();
template <typename = void>
_CCCL_DEVICE static inline _CUDA_VSTD::uint32_t bfind_shiftamt(_CUDA_VSTD::int64_t __a_reg)
{
# if _CCCL_CUDA_COMPILER(NVHPC) || __CUDA_ARCH__ >= 500
_CUDA_VSTD::uint32_t __dest;
asm("bfind.shiftamt.s64 %0, %1;" : "=r"(__dest) : "l"(__a_reg) :);
return __dest;
# else
// Unsupported architectures will have a linker error with a semi-decent error message
__cuda_ptx_bfind_shiftamt_is_not_supported_before_SM_50__();
return 0;
# endif
}
#endif // __cccl_ptx_isa >= 200
#endif // _CUDA_PTX_GENERATED_BFIND_H_